@@ -21,4 +21,4 @@
 """Collection of Estonian numbers."""
 
 # provide vat as an alias
-from stdnum.ee import kmkr as vat
+from stdnum.ee import kmkr as vat  # noqa: F401
